\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{pnwart}
[2018/12/16 v1.57 Typesetting articles for the PNW Press]
\def\@classname{pnwart}
\InputIfFileExists{pnwart-preload-hook.tex}{%
  \ClassWarning{\@classname}{%
    I am loading pnwart-preload-hook.tex. You are fully responsible
    for any problems from now on.}}{}
\RequirePackage{xkeyval}
\RequirePackage{xstring}
\define@choicekey*+{pnwart.cls}{format}[\PNW@format\PNW@format@nr]{%
  manuscript, pnwsmall, pnwlarge}[manuscript]{}{%
  \ClassError{\@classname}{The option format must be manuscript, pnwsmall, pnwlarge}}
\def\@DeclarePNWFormat#1{\DeclareOptionX{#1}{\setkeys{pnwart.cls}{format=#1}}}
\@DeclarePNWFormat{manuscript}
\@DeclarePNWFormat{pnwsmall}
\@DeclarePNWFormat{pnwlarge}
\ExecuteOptionsX{format}
\define@boolkey+{pnwart.cls}[@PNW@]{screen}[true]{%
  \if@PNW@screen
    \PackageInfo{\@classname}{Using screen mode}%
  \else
    \PackageInfo{\@classname}{Not using screen mode}%
  \fi}{\PackageError{\@classname}{The option screen can be either true or
    false}}
\ExecuteOptionsX{screen=false}
\define@boolkey+{pnwart.cls}[@PNW@]{pnwthm}[true]{%
  \if@PNW@pnwthm
    \PackageInfo{\@classname}{Requiring pnwthm}%
  \else
    \PackageInfo{\@classname}{Suppressing pnwthm}%
  \fi}{\PackageError{\@classname}{The option pnwthm can be either true or
    false}}
\ExecuteOptionsX{pnwthm=true}
\define@boolkey+{pnwart.cls}[@PNW@]{review}[true]{%
  \if@PNW@review
    \PackageInfo{\@classname}{Using review mode}%
    \AtBeginDocument{\@PNW@printfoliostrue}%
  \else
    \PackageInfo{\@classname}{Not using review mode}%
  \fi}{\PackageError{\@classname}{The option review can be either true or
    false}}
\ExecuteOptionsX{review=false}
\define@boolkey+{pnwart.cls}[@PNW@]{authorversion}[true]{%
  \if@PNW@authorversion
    \PackageInfo{\@classname}{Using authorversion mode}%
  \else
    \PackageInfo{\@classname}{Not using authorversion mode}%
  \fi}{\PackageError{\@classname}{The option authorversion can be either true or
    false}}
\ExecuteOptionsX{authorversion=false}
\define@boolkey+{pnwart.cls}[@PNW@]{nonpnw}[true]{%
  \if@PNW@nonpnw
    \PackageInfo{\@classname}{Using nonpnw mode}%
    \AtBeginDocument{\@PNW@printpnwreffalse}%
    % in 'nonpnw' mode we disable the "PNW Reference Format"
    % printing by default, but this can be re-enabled by the
    % user using \settopmatter{printpnwref=true}
  \else
    \PackageInfo{\@classname}{Not using nonpnw mode}%
  \fi}{\PackageError{\@classname}{The option nonpnw can be either true or
    false}}
\ExecuteOptionsX{nonpnw=false}
\define@boolkey+{pnwart.cls}[@PNW@]{balance}[true]{}{%
  \PackageError{\@classname}{The option balance can be either true or
    false}}
\ExecuteOptionsX{balance}
\define@boolkey+{pnwart.cls}[@PNW@]{natbib}[true]{%
  \if@PNW@natbib
    \PackageInfo{\@classname}{Explicitly selecting natbib mode}%
  \else
    \PackageInfo{\@classname}{Explicitly deselecting natbib mode}%
  \fi}{\PackageError{\@classname}{The option natbib can be either true or
    false}}
\ExecuteOptionsX{natbib=true}
\define@boolkey+{pnwart.cls}[@PNW@]{anonymous}[true]{%
  \if@PNW@anonymous
    \PackageInfo{\@classname}{Using anonymous mode}%
  \else
    \PackageInfo{\@classname}{Not using anonymous mode}%
  \fi}{\PackageError{\@classname}{The option anonymous can be either true or
    false}}
\ExecuteOptionsX{anonymous=false}
\define@boolkey+{pnwart.cls}[@PNW@]{timestamp}[true]{%
  \if@PNW@timestamp
    \PackageInfo{\@classname}{Using timestamp mode}%
  \else
    \PackageInfo{\@classname}{Not using timestamp mode}%
  \fi}{\PackageError{\@classname}{The option timestamp can be either true or
    false}}
\ExecuteOptionsX{timestamp=false}
\define@boolkey+{pnwart.cls}[@PNW@]{authordraft}[true]{%
  \if@PNW@authordraft
    \PackageInfo{\@classname}{Using authordraft mode}%
    \@PNW@timestamptrue
    \@PNW@reviewtrue
  \else
    \PackageInfo{\@classname}{Not using authordraft mode}%
  \fi}{\PackageError{\@classname}{The option authordraft can be either true or
    false}}
\ExecuteOptionsX{authordraft=false}
\def\PNW@fontsize{}
\DeclareOptionX{9pt}{\edef\PNW@fontsize{\CurrentOption}}
\DeclareOptionX{10pt}{\edef\PNW@fontsize{\CurrentOption}}
\DeclareOptionX{11pt}{\edef\PNW@fontsize{\CurrentOption}}
\DeclareOptionX{12pt}{\edef\PNW@fontsize{\CurrentOption}}
\DeclareOptionX{draft}{\PassOptionsToClass{\CurrentOption}{amsart}}
\DeclareOptionX{*}{\PassOptionsToClass{\CurrentOption}{amsart}}
\ProcessOptionsX
\ClassInfo{\@classname}{Using format \PNW@format, number \PNW@format@nr}
\newif\if@PNW@manuscript
\newif\if@PNW@journal
\newif\if@PNW@conferencemode
\ifnum\PNW@format@nr=5\relax % siggraph
  \ClassWarning{\@classname}{The format siggraph is now obsolete.
    I am switching to sigconf.}
  \setkeys{pnwart.cls}{format=sigconf}
\fi
\ifnum\PNW@format@nr=0\relax
  \@PNW@manuscripttrue
\else
  \@PNW@manuscriptfalse
\fi
\@PNW@conferencemodefalse
\ifcase\PNW@format@nr
\relax % manuscript
  \@PNW@journaltrue
\or % pnwsmall
  \@PNW@journaltrue
\or % pnwlarge
  \@PNW@journaltrue
\fi
\ifx\PNW@fontsize\@empty
  \ifcase\PNW@format@nr
  \relax % manuscript
    \def\PNW@fontsize{9pt}%
  \or % pnwsmall
    \def\PNW@fontsize{10pt}%
  \or % pnwlarge
  \fi
\fi
\ClassInfo{\@classname}{Using fontsize \PNW@fontsize}
\LoadClass[\PNW@fontsize, reqno]{amsart}
\RequirePackage{microtype}
\RequirePackage{etoolbox}
\RequirePackage{booktabs}
\RequirePackage{refcount}
\RequirePackage{totpages}
\RequirePackage{environ}
\if@PNW@manuscript
\RequirePackage{setspace}
\onehalfspacing
\fi
\RequirePackage{textcase}
\if@PNW@natbib
  \RequirePackage{natbib}
  \renewcommand{\bibsection}{%
     \section*{\refname}%
     \phantomsection\addcontentsline{toc}{section}{\refname}%
  }
  \renewcommand{\bibfont}{\bibliofont}
  \renewcommand\setcitestyle[1]{
  \@for\@tempa:=#1\do
  {\def\@tempb{round}\ifx\@tempa\@tempb
     \renewcommand\NAT@open{(}\renewcommand\NAT@close{)}\fi
   \def\@tempb{square}\ifx\@tempa\@tempb
     \renewcommand\NAT@open{[}\renewcommand\NAT@close{]}\fi
   \def\@tempb{angle}\ifx\@tempa\@tempb
     \renewcommand\NAT@open{$<$}\renewcommand\NAT@close{$>$}\fi
   \def\@tempb{curly}\ifx\@tempa\@tempb
     \renewcommand\NAT@open{\{}\renewcommand\NAT@close{\}}\fi
   \def\@tempb{semicolon}\ifx\@tempa\@tempb
     \renewcommand\NAT@sep{;}\fi
   \def\@tempb{colon}\ifx\@tempa\@tempb
     \renewcommand\NAT@sep{;}\fi
   \def\@tempb{comma}\ifx\@tempa\@tempb
     \renewcommand\NAT@sep{,}\fi
   \def\@tempb{authoryear}\ifx\@tempa\@tempb
     \NAT@numbersfalse\fi
   \def\@tempb{numbers}\ifx\@tempa\@tempb
     \NAT@numberstrue\NAT@superfalse\fi
   \def\@tempb{super}\ifx\@tempa\@tempb
     \NAT@numberstrue\NAT@supertrue\fi
   \def\@tempb{nobibstyle}\ifx\@tempa\@tempb
     \let\bibstyle=\@gobble\fi
   \def\@tempb{bibstyle}\ifx\@tempa\@tempb
     \let\bibstyle=\@citestyle\fi
   \def\@tempb{sort}\ifx\@tempa\@tempb
     \def\NAT@sort{\@ne}\fi
   \def\@tempb{nosort}\ifx\@tempa\@tempb
     \def\NAT@sort{\z@}\fi
   \def\@tempb{compress}\ifx\@tempa\@tempb
     \def\NAT@cmprs{\@ne}\fi
   \def\@tempb{nocompress}\ifx\@tempa\@tempb
     \def\NAT@cmprs{\z@}\fi
   \def\@tempb{sort&compress}\ifx\@tempa\@tempb
     \def\NAT@sort{\@ne}\def\NAT@cmprs{\@ne}\fi
   \def\@tempb{mcite}\ifx\@tempa\@tempb
     \let\NAT@merge\@ne\fi
   \def\@tempb{merge}\ifx\@tempa\@tempb
     \@ifnum{\NAT@merge<\tw@}{\let\NAT@merge\tw@}{}\fi
   \def\@tempb{elide}\ifx\@tempa\@tempb
     \@ifnum{\NAT@merge<\thr@@}{\let\NAT@merge\thr@@}{}\fi
   \def\@tempb{longnamesfirst}\ifx\@tempa\@tempb
     \NAT@longnamestrue\fi
   \def\@tempb{nonamebreak}\ifx\@tempa\@tempb
     \def\NAT@nmfmt#1{\mbox{\NAT@up#1}}\fi
   \expandafter\NAT@find@eq\@tempa=\relax\@nil
   \if\@tempc\relax\else
     \expandafter\NAT@rem@eq\@tempc
     \def\@tempb{open}\ifx\@tempa\@tempb
      \xdef\NAT@open{\@tempc}\fi
     \def\@tempb{close}\ifx\@tempa\@tempb
      \xdef\NAT@close{\@tempc}\fi
     \def\@tempb{aysep}\ifx\@tempa\@tempb
      \xdef\NAT@aysep{\@tempc}\fi
     \def\@tempb{yysep}\ifx\@tempa\@tempb
      \xdef\NAT@yrsep{\@tempc}\fi
     \def\@tempb{notesep}\ifx\@tempa\@tempb
      \xdef\NAT@cmt{\@tempc}\fi
     \def\@tempb{citesep}\ifx\@tempa\@tempb
      \xdef\NAT@sep{\@tempc}\fi
   \fi
  }%
  \NAT@@setcites
  }
  \renewcommand\citestyle[1]{%
    \ifcsname bibstyle@#1\endcsname%
    \csname bibstyle@#1\endcsname\let\bibstyle\@gobble%
    \else%
    \@latex@error{Undefined `#1' citestyle}%
    \fi
  }%
\fi
\newcommand{\bibstyle@pnwauthoryear}{%
  \setcitestyle{%
    authoryear,%
    open={[},close={]},citesep={;},%
    aysep={},yysep={,},%
    notesep={, }}}
\newcommand{\bibstyle@pnwnumeric}{%
  \setcitestyle{%
    numbers,sort&compress,%
    open={[},close={]},citesep={,},%
    notesep={, }}}
\if@PNW@natbib
\citestyle{pnwnumeric}
\fi
\def\@startsection#1#2#3#4#5#6{%
  \if@noskipsec \leavevmode \fi
  \par
  \@tempskipa #4\relax
  \@afterindenttrue
  \ifdim \@tempskipa <\z@
    \@tempskipa -\@tempskipa \@afterindentfalse
  \fi
  \if@nobreak
    \everypar{}%
  \else
    \addpenalty\@secpenalty\addvspace\@tempskipa
  \fi
  \@ifstar
    {\@ssect{#3}{#4}{#5}{#6}}%
    {\@dblarg{\@sect{#1}{#2}{#3}{#4}{#5}{#6}}}}
\def\@sect#1#2#3#4#5#6[#7]#8{%
  \edef\@toclevel{\ifnum#2=\@m 0\else\number#2\fi}%
  \ifnum #2>\c@secnumdepth
    \let\@svsec\@empty
  \else
    \refstepcounter{#1}%
    \protected@edef\@svsec{\@seccntformat{#1}\relax}%
  \fi
  \@tempskipa #5\relax
  \ifdim \@tempskipa>\z@
    \begingroup
      #6{%
        \@hangfrom{\hskip #3\relax\@svsec}%
          \interlinepenalty \@M #8\@@par}%
    \endgroup
    \csname #1mark\endcsname{#7}%
    \ifnum #2>\c@secnumdepth \else
        \@tochangmeasure{\csname the#1\endcsname}%
    \fi
    \addcontentsline{toc}{#1}{%
      \ifnum #2>\c@secnumdepth \else
        \protect\numberline{\csname the#1\endcsname}%
      \fi
      #7}%
  \else
    \def\@svsechd{%
      #6{\hskip #3\relax
      \@svsec #8}%
      \csname #1mark\endcsname{#7}%
      \ifnum #2>\c@secnumdepth \else
        \@tochangmeasure{\csname the#1\endcsname\space}%
      \fi
      \addcontentsline{toc}{#1}{%
        \ifnum #2>\c@secnumdepth \else
          \protect\numberline{\csname the#1\endcsname}%
        \fi
        #7}}%
  \fi
  \@xsect{#5}}
\def\@xsect#1{%
  \@tempskipa #1\relax
  \ifdim \@tempskipa>\z@
    \par \nobreak
    \vskip \@tempskipa
    \@afterheading
  \else
    \@nobreakfalse
    \global\@noskipsectrue
    \everypar{%
      \if@noskipsec
        \global\@noskipsecfalse
       {\setbox\z@\lastbox}%
        \clubpenalty\@M
        \begingroup \@svsechd \endgroup
        \unskip
        \@tempskipa #1\relax
        \hskip -\@tempskipa
      \else
        \clubpenalty \@clubpenalty
        \everypar{}%
      \fi}%
  \fi
  \ignorespaces}
\def\@seccntformat#1{\csname the#1\endcsname\quad}
\def\@ssect#1#2#3#4#5{%
  \@tempskipa #3\relax
  \ifdim \@tempskipa>\z@
    \begingroup
      #4{%
        \@hangfrom{\hskip #1}%
          \interlinepenalty \@M #5\@@par}%
    \endgroup
  \else
    \def\@svsechd{#4{\hskip #1\relax #5}}%
  \fi
  \@xsect{#3}}
\def\@starttoc#1#2{\begingroup\makeatletter
  \setTrue{#1}%
  \par\removelastskip\vskip\z@skip
  \@startsection{section}\@M\z@{\linespacing\@plus\linespacing}%
    {.5\linespacing}{\centering\contentsnamefont}{#2}%
  \@input{\jobname.#1}%
  \if@filesw
    \@xp\newwrite\csname tf@#1\endcsname
    \immediate\@xp\openout\csname tf@#1\endcsname \jobname.#1\relax
  \fi
  \global\@nobreakfalse \endgroup
  \addvspace{32\p@\@plus14\p@}%
}
\def\l@section{\@tocline{1}{0pt}{1pc}{2pc}{}}
\def\l@subsection{\@tocline{2}{0pt}{1pc}{3pc}{}}
\def\l@subsubsection{\@tocline{2}{0pt}{1pc}{5pc}{}}
\def\@makefntext{\noindent\@makefnmark}
\if@PNW@conferencemode
\long\def\@footnotetext#1{\marginpar{%
    \reset@font\small
    \interlinepenalty\interfootnotelinepenalty
    \protected@edef\@currentlabel{%
       \csname p@footnote\endcsname\@thefnmark
    }%
    \color@begingroup
      \@makefntext{%
        \rule\z@\footnotesep\ignorespaces#1\@finalstrut\strutbox}%
    \color@endgroup}}%
\fi
\long\def\@mpfootnotetext#1{%
  \global\setbox\@mpfootins\vbox{%
    \unvbox\@mpfootins
    \reset@font\footnotesize
    \hsize\columnwidth
    \@parboxrestore
    \protected@edef\@currentlabel
         {\csname p@mpfootnote\endcsname\@thefnmark}%
    \color@begingroup\centering
      \@makefntext{%
        \rule\z@\footnotesep\ignorespaces#1\@finalstrut\strutbox}%
    \color@endgroup}}
\def\@makefnmark{\hbox{\@textsuperscript{\normalfont\@thefnmark}}}
\let\@footnotemark@nolink\@footnotemark
\let\@footnotetext@nolink\@footnotetext
\RequirePackage[bookmarksnumbered,unicode]{hyperref}
\pdfstringdefDisableCommands{%
  \def\unskip{}%
  \def\textbullet{- }%
  \def\textrightarrow{ -> }%
  \def\footnotemark{}%
}
\urlstyle{rm}
\ifcase\PNW@format@nr
\relax % manuscript
\or % pnwsmall
\or % pnwlarge
\fi
\AtEndPreamble{%
  \if@PNW@screen
    \hypersetup{colorlinks,
      linkcolor=PNWPurple,
      citecolor=PNWPurple,
      urlcolor=PNWDarkBlue,
      filecolor=PNWDarkBlue}
    \else
    \hypersetup{hidelinks}
  \fi
  \hypersetup{pdflang={en},
    pdfdisplaydoctitle}}
\if@PNW@natbib
  \let\citeN\cite
  \let\cite\citep
  \let\citeANP\citeauthor
  \let\citeNN\citeyearpar
  \let\citeyearNP\citeyear
  \let\citeNP\citealt
  \DeclareRobustCommand\citeA
     {\begingroup\NAT@swafalse
       \let\NAT@ctype\@ne\NAT@partrue\NAT@fullfalse\NAT@open\NAT@citetp}%
  \providecommand\newblock{}%
\else
  \AtBeginDocument{%
    \let\shortcite\cite%
    \providecommand\citename[1]{#1}}
\fi
\newcommand\shortcite[2][]{%
  \ifNAT@numbers\cite[#1]{#2}\else\citeyearpar[#1]{#2}\fi}
\def\bibliographystyle#1{%
  \ifx\@begindocumenthook\@undefined\else
    \expandafter\AtBeginDocument
  \fi
    {\if@filesw
       \immediate\write\@auxout{\string\bibstyle{#1}}%
     \fi}}
\RequirePackage{graphicx}
\RequirePackage[prologue]{xcolor}
\definecolor[named]{PNWBlue}{cmyk}{1,0.1,0,0.1}
\definecolor[named]{PNWYellow}{cmyk}{0,0.16,1,0}
\definecolor[named]{PNWOrange}{cmyk}{0,0.42,1,0.01}
\definecolor[named]{PNWRed}{cmyk}{0,0.90,0.86,0}
\definecolor[named]{PNWLightBlue}{cmyk}{0.49,0.01,0,0}
\definecolor[named]{PNWGreen}{cmyk}{0.20,0,1,0.19}
\definecolor[named]{PNWPurple}{cmyk}{0.55,1,0,0.15}
\definecolor[named]{PNWDarkBlue}{cmyk}{1,0.58,0,0.21}
\if@PNW@authordraft
  \RequirePackage{draftwatermark}
  \SetWatermarkFontSize{0.5in}
  \SetWatermarkColor[gray]{.9}
  \SetWatermarkText{\parbox{12em}{\centering
      Unpublished working draft.\\
      Not for distribution.}}
\fi
\RequirePackage{geometry}
\ifcase\PNW@format@nr
\relax % manuscript
   \geometry{letterpaper,head=13pt,
   marginparwidth=6pc,heightrounded}%
\or % pnwsmall
   \geometry{twoside=true,
     includeheadfoot, head=13pt, foot=2pc,
     paperwidth=6.75in, paperheight=10in,
     top=58pt, bottom=44pt, inner=46pt, outer=46pt,
     marginparwidth=2pc,heightrounded
   }%
\or % pnwlarge
   \geometry{twoside=true, head=13pt, foot=2pc,
     paperwidth=8.5in, paperheight=11in,
     includeheadfoot,
     top=78pt, bottom=114pt, inner=81pt, outer=81pt,
     marginparwidth=4pc,heightrounded
     }%
\fi
\setlength\parindent{10\p@}
\setlength\parskip{\z@}
\ifcase\PNW@format@nr
\relax % manuscript
\or % pnwsmall
\or % pnwlarge
\fi
\setlength\normalparindent{\parindent}
\def\copyrightpermissionfootnoterule{\kern-3\p@
  \hrule \@width \columnwidth \kern 2.6\p@}
\RequirePackage{manyfoot}
\SelectFootnoteRule[2]{copyrightpermission}
\DeclareNewFootnote{authorsaddresses}
\SelectFootnoteRule[2]{copyrightpermission}
\DeclareNewFootnote{copyrightpermission}
\def\footnoterule{\kern-3\p@
  \hrule \@width 4pc \kern 2.6\p@}
\def\endminipage{%
    \par
    \unskip
    \ifvoid\@mpfootins\else
      \vskip\skip\@mpfootins
      \normalcolor
      \unvbox\@mpfootins
    \fi
    \@minipagefalse
  \color@endgroup
  \egroup
  \expandafter\@iiiparbox\@mpargs{\unvbox\@tempboxa}}
\def\@textbottom{\vskip \z@ \@plus 1pt}
\let\@texttop\relax
\ifcase\PNW@format@nr
\relax % manuscript
\or % pnwsmall
\or % pnwlarge
\fi
\RequirePackage{iftex}
\ifPDFTeX
\input{glyphtounicode}
\pdfglyphtounicode{f_f}{FB00}
\pdfglyphtounicode{f_f_i}{FB03}
\pdfglyphtounicode{f_f_l}{FB04}
\pdfglyphtounicode{f_i}{FB01}
\pdfglyphtounicode{t_t}{0074 0074}
\pdfglyphtounicode{f_t}{0066 0074}
\pdfglyphtounicode{T_h}{0054 0068}
\pdfgentounicode=1
\fi
\RequirePackage{cmap}
\newif\if@PNW@newfonts
\@PNW@newfontstrue
\IfFileExists{libertine.sty}{}{\ClassWarning{\@classname}{You do not
    have the libertine package installed.  Please upgrade your
    TeX}\@PNW@newfontsfalse}
\IfFileExists{zi4.sty}{}{\ClassWarning{\@classname}{You do not
    have the zi4 package installed.  Please upgrade your
    TeX}\@PNW@newfontsfalse}
\IfFileExists{newtxmath.sty}{}{\ClassWarning{\@classname}{You do not
    have the newtxmath package installed.  Please upgrade your
    TeX}\@PNW@newfontsfalse}
\if@PNW@newfonts
  \RequirePackage[T1]{fontenc}
\ifxetex
  \RequirePackage[tt=false]{libertine}
  \setmonofont{inconsolata}
\else
  \RequirePackage[tt=false, type1=true]{libertine}
\fi
\RequirePackage[varqu]{zi4}
\RequirePackage[libertine]{newtxmath}
\fi
\let\liningnums\@undefined
\AtEndPreamble{%
  \DeclareTextFontCommand{\liningnums}{\libertineLF}}
\if@PNW@conferencemode
  \renewcommand{\familydefault}{\sfdefault}
\fi
\newif\if@Description@present
\@Description@presenttrue
\newif\if@undescribed@images
\@undescribed@imagesfalse
\newcommand\Description[2][]{\global\@Description@presenttrue}
\AtEndDocument{\if@undescribed@images
  \ClassWarningNoLine{\@classname}{Some images may lack descriptions}\fi}
\AtBeginEnvironment{figure}{\@Description@presentfalse}
\AtBeginEnvironment{figure*}{\@Description@presentfalse}
\AtEndEnvironment{figure}{\if@Description@present\else
  \global\@undescribed@imagestrue
  \ClassWarning{\@classname}{A possible image without description}\fi}
\AtEndEnvironment{figure*}{\if@Description@present\else
  \global\@undescribed@imagestrue
  \ClassWarning{\@classname}{A possible image without description}\fi}
\RequirePackage{caption, float}
\captionsetup[table]{position=top}
\if@PNW@journal
  \captionsetup{labelfont={sf, small},
    textfont={sf, small}, margin=\z@}
  \captionsetup[figure]{name={Fig.}}
\else
  \captionsetup{labelfont={bf},
    textfont={bf}, labelsep=colon, margin=\z@}
  \ifcase\PNW@format@nr
  \relax % manuscript
  \or % pnwsmall
  \or % pnwlarge
  \fi
\fi
\newfloat{sidebar}{}{sbar}
\floatname{sidebar}{Sidebar}
\renewenvironment{sidebar}{\Collect@Body\@sidebar}{}
\long\def\@sidebar#1{\bgroup\captionsetup{type=sidebar}%
  \marginpar{\small#1}\egroup}
\newenvironment{marginfigure}{\Collect@Body\@marginfigure}{}
\long\def\@marginfigure#1{\bgroup
  \captionsetup{type=figure}%
  \marginpar{\@Description@presentfalse\centering
    \small#1\if@Description@present\else
      \global\@undescribed@imagestrue
      \ClassWarning{\@classname}{A possible image without description}
      \fi}%
  \egroup}
\newenvironment{margintable}{\Collect@Body\@margintable}{}
\long\def\@margintable#1{\bgroup\captionsetup{type=table}%
  \marginpar{\centering\small#1}\egroup}
\newdimen\fulltextwidth
\fulltextwidth=\dimexpr(\textwidth+\marginparwidth+\marginparsep)
\if@PNW@conferencemode
\def\@dblfloat{\bgroup\columnwidth=\fulltextwidth
  \let\@endfloatbox\@endwidefloatbox
  \def\@fpsadddefault{\def\@fps{tp}}%
  \@float}
\fi
\if@PNW@conferencemode
\def\end@dblfloat{%
    \end@float\egroup}
\fi
\def\@endwidefloatbox{%
  \par\vskip\z@skip
  \@minipagefalse
  \outer@nobreak
  \egroup
  \color@endbox
  \global\setbox\@currbox=\vbox{\moveleft
    \dimexpr(\fulltextwidth-\textwidth)\box\@currbox}%
  \wd\@currbox=\textwidth
}
\ifcase\PNW@format@nr
\relax % manuscript
\or % pnwsmall
\or % pnwlarge
\fi
\newdimen\@PNW@labelwidth
\AtBeginDocument{%
  \setlength\labelsep{4pt}
  \setlength{\@PNW@labelwidth}{6.5pt}

  %% First-level list: when beginning after the first line of an
  %% indented paragraph or ending before an indented paragraph, labels
  %% should not hang to the left of the preceding/following text.
  \setlength\leftmargini{\z@}
  \addtolength\leftmargini{\parindent}
  \addtolength\leftmargini{2\labelsep}
  \addtolength\leftmargini{\@PNW@labelwidth}

  %% Second-level and higher lists.
  \setlength\leftmarginii{\z@}
  \addtolength\leftmarginii{0.5\labelsep}
  \addtolength\leftmarginii{\@PNW@labelwidth}
  \setlength\leftmarginiii{\leftmarginii}
  \setlength\leftmarginiv{\leftmarginiii}
  \setlength\leftmarginv{\leftmarginiv}
  \setlength\leftmarginvi{\leftmarginv}
  \@listi}
\newskip\listisep
\listisep\smallskipamount
\def\@listI{\leftmargin\leftmargini
  \labelwidth\leftmargini \advance\labelwidth-\labelsep
  \listparindent\z@
  \topsep\listisep}
\let\@listi\@listI
\def\@listii{\leftmargin\leftmarginii
  \labelwidth\leftmarginii \advance\labelwidth-\labelsep
  \topsep\z@skip}
\def\@listiii{\leftmargin\leftmarginiii
  \labelwidth\leftmarginiii \advance\labelwidth-\labelsep}
\def\@listiv{\leftmargin\leftmarginiv
  \labelwidth\leftmarginiv \advance\labelwidth-\labelsep}
\def\@listv{\leftmargin\leftmarginv
  \labelwidth\leftmarginv \advance\labelwidth-\labelsep}
\def\@listvi{\leftmargin\leftmarginvi
  \labelwidth\leftmarginvi \advance\labelwidth-\labelsep}
\renewcommand{\descriptionlabel}[1]{\upshape\bfseries #1}
\renewenvironment{description}{\list{}{%
    \labelwidth\@PNW@labelwidth
    \let\makelabel\descriptionlabel}%
}{
  \endlist
}
\let\enddescription=\endlist % for efficiency
\define@choicekey*+{PNW}{pnwJournal}[\@journalCode\@journalCode@nr]{%
  EDTECH,%
}{%
\ifcase\@journalCode@nr
\relax % EDTECH
  \def\@journalName{Education and Technology}%
  \def\@journalNameShort{Education and Technology}%
  \def\@permissionCodeOne{PNW-R}%
\fi
\ClassInfo{\@classname}{Using journal code \@journalCode}%
}{%
  \ClassError{\@classname}{Incorrect journal #1}%
}%
\def\pnwJournal#1{\setkeys{PNW}{pnwJournal=#1}}
\def\@journalCode@nr{0}
\def\@journalName{}%
\def\@journalNameShort{\@journalName}%
\def\@permissionCodeOne{XXXX-XXXX}%
\def\@permissionCodeTwo{}%
\newcommand\pnwConference[4][]{%
  \gdef\pnwConference@shortname{#1}%
  \gdef\pnwConference@name{#2}%
  \gdef\pnwConference@date{#3}%
  \gdef\pnwConference@venue{#4}%
  \ifx\pnwConference@shortname\@empty
    \gdef\pnwConference@shortname{#2}%
  \fi}
\def\@editorsAbbrev{(Ed.)}
\def\@pnwEditors{}
\def\editor#1{\ifx\@pnwEditors\@empty
    \gdef\@pnwEditors{#1}%
  \else
    \gdef\@editorsAbbrev{(Eds.)}%
    \g@addto@macro\@pnwEditors{\and#1}%
\fi}
\def\subtitle#1{\def\@subtitle{#1}}
\subtitle{}
\newcount\num@authorgroups
\num@authorgroups=0\relax
\newcount\num@authors
\num@authors=0\relax
\newif\if@insideauthorgroup
\@insideauthorgroupfalse
\renewcommand\author[2][]{%
  \IfSubStr{#2}{,}{\ClassWarning{\@classname}{Do not put several
      authors in the same \string\author\space macro!}}{}%
  \global\advance\num@authors by 1\relax
  \if@insideauthorgroup\else
    \global\advance\num@authorgroups by 1\relax
    \global\@insideauthorgrouptrue
  \fi
  \ifx\addresses\@empty
    \if@PNW@anonymous
      \gdef\addresses{\@author{Anonymous Author(s)%
        \ifx\@pnwSubmissionID\@empty\else\\Submission Id:
          \@pnwSubmissionID\fi}}%
      \gdef\authors{Anonymous Author(s)}%
    \else
      \gdef\addresses{\@author{#2}}%
      \gdef\authors{#2}%
    \fi
  \else
    \if@PNW@anonymous\else
      \g@addto@macro\addresses{\and\@author{#2}}%
      \g@addto@macro\authors{\and#2}%
    \fi
  \fi
  \if@PNW@anonymous
    \ifx\shortauthors\@empty
      \gdef\shortauthors{Anon.
        \ifx\@pnwSubmissionID\@empty\else Submission Id:
        \@pnwSubmissionID\fi}%
    \fi
  \else
    \def\@tempa{#1}%
    \ifx\@tempa\@empty
      \ifx\shortauthors\@empty
        \gdef\shortauthors{#2}%
      \else
        \g@addto@macro\shortauthors{\and#2}%
      \fi
    \else
      \ifx\shortauthors\@empty
        \gdef\shortauthors{#1}%
      \else
        \g@addto@macro\shortauthors{\and#1}%
      \fi
    \fi
  \fi}
\newcommand{\affiliation}[2][]{%
  \global\@insideauthorgroupfalse
  \if@PNW@anonymous\else
    \g@addto@macro\addresses{\affiliation{#1}{#2}}%
  \fi}
\define@boolkey+{@PNW@affiliation@}[@PNW@affiliation@]{obeypunctuation}%
[true]{}{\ClassError{\@classname}{The option obeypunctuation can be either true or false}}
\def\additionalaffiliation#1{\authornote{\@additionalaffiliation{#1}}}
\def\@additionalaffiliation#1{\bgroup
  \def\position##1{\ignorespaces}%
  \def\institution##1{##1\ignorespaces}%
  \def\department{\@ifnextchar[{\@department}{\@department[]}}%
  \def\@department[##1]##2{\unskip, ##2\ignorespaces}%
  \let\streetaddress\position
  \let\city\position
  \let\state\position
  \let\postcode\position
  \let\country\position
  Also with #1\unskip.\egroup}
\renewcommand{\email}[2][]{%
  \IfSubStr{#2}{,}{\ClassWarning{\@classname}{Do not put several
      addresses in the same \string\email\space macro!}}{}%
  \if@PNW@anonymous\else
    \g@addto@macro\addresses{\email{#1}{#2}}%
  \fi}
\def\orcid#1{\unskip\ignorespaces}
\def\authorsaddresses#1{\def\@authorsaddresses{#1}}
\authorsaddresses{\@mkauthorsaddresses}
\def\@titlenotes{}
\def\titlenote#1{%
  \g@addto@macro\@title{\footnotemark}%
  \if@PNW@anonymous
    \g@addto@macro\@titlenotes{%
      \stepcounter{footnote}\footnotetext{Title note}}%
  \else
    \g@addto@macro\@titlenotes{\stepcounter{footnote}\footnotetext{#1}}%
  \fi}
\def\@subtitlenotes{}
\def\subtitlenote#1{%
  \g@addto@macro\@subtitle{\footnotemark}%
  \if@PNW@anonymous
    \g@addto@macro\@subtitlenotes{%
      \stepcounter{footnote}\footnotetext{Subtitle note}}%
  \else
    \g@addto@macro\@subtitlenotes{%
      \stepcounter{footnote}\footnotetext{#1}}%
  \fi}
\def\@authornotes{}
\def\authornote#1{%
  \if@PNW@anonymous\else
    \g@addto@macro\addresses{\@authornotemark}%
    \g@addto@macro\@authornotes{%
      \stepcounter{footnote}\footnotetext{#1}}%
  \fi}
\newcommand\authornotemark[1][\relax]{%
  \ifx#1\relax\relax\relax
  \g@addto@macro\addresses{\@authornotemark}%
  \else
  \g@addto@macro\addresses{\@@authornotemark{#1}}%
  \fi}
\def\pnwVolume#1{\def\@pnwVolume{#1}}
\pnwVolume{1}
\def\pnwNumber#1{\def\@pnwNumber{#1}}
\pnwNumber{1}
\def\pnwArticle#1{\def\@pnwArticle{#1}}
\pnwArticle{}
\def\pnwArticleSeq#1{\def\@pnwArticleSeq{#1}}
\pnwArticleSeq{\@pnwArticle}
\def\pnwYear#1{\def\@pnwYear{#1}}
\pnwYear{\the\year}
\def\pnwMonth#1{\def\@pnwMonth{#1}}
\pnwMonth{\the\month}
\def\@pnwPubDate{\ifcase\@pnwMonth\or
  January\or February\or March\or April\or May\or June\or
  July\or August\or September\or October\or November\or
  December\fi~\@pnwYear}
\def\pnwPrice#1{\def\@pnwPrice{#1}}
\pnwPrice{0.0}
\def\pnwSubmissionID#1{\def\@pnwSubmissionID{#1}}
\pnwSubmissionID{}
\def\pnwISBN#1{\def\@pnwISBN{#1}}
\pnwISBN{978-x-xxxx-xxxx-x/YY/MM}
\def\pnwDOI#1{\def\@pnwDOI{#1}}
\pnwDOI{10.1145/nnnnnnn.nnnnnnn}
\newif\if@PNW@badge
\@PNW@badgefalse
\newlength\@PNW@badge@width
\setlength\@PNW@badge@width{5pc}
\newlength\@PNW@title@width
\newlength\@PNW@badge@skip
\setlength\@PNW@badge@skip{1pc}
\newcommand\pnwBadgeR[2][]{\@PNW@badgetrue
  \def\@pnwBadgeR@url{#1}%
  \def\@pnwBadgeR@image{#2}}
\def\@pnwBadgeR@url{}
\def\@pnwBadgeR@image{}
\newcommand\pnwBadgeL[2][]{\@PNW@badgetrue
  \def\@pnwBadgeL@url{#1}%
  \def\@pnwBadgeL@image{#2}}
\def\@pnwBadgeL@url{}
\def\@pnwBadgeL@image{}
\def\startPage#1{\def\@startPage{#1}}
\startPage{}
\def\terms#1{\ClassWarning{\@classname}{The command \string\terms{} is
    obsolete.  I am going to ignore it}}
\def\keywords#1{\def\@keywords{#1}}
\keywords{}
\renewenvironment{abstract}{\Collect@Body\@saveabstract}{}
\long\def\@saveabstract#1{\long\gdef\@abstract{#1}}
\@saveabstract{}
\long\def\@lempty{}
\define@boolkey+{@PNW@topmatter@}[@PNW@]{printccs}[true]{%
  \if@PNW@printccs
    \ClassInfo{\@classname}{Printing CCS}%
  \else
    \ClassInfo{\@classname}{Suppressing CCS}%
  \fi}{\ClassError{\@classname}{The option printccs can be either true or false}}
\define@boolkey+{@PNW@topmatter@}[@PNW@]{printpnwref}[true]{%
  \if@PNW@printpnwref
    \ClassInfo{\@classname}{Printing bibformat}%
  \else
    \ClassInfo{\@classname}{Suppressing bibformat}%
  \fi}{\ClassError{\@classname}{The option printpnwref can be either true or false}}
\define@boolkey+{@PNW@topmatter@}[@PNW@]{printfolios}[true]{%
  \if@PNW@printfolios
    \ClassInfo{\@classname}{Printing folios}%
  \else
    \ClassInfo{\@classname}{Suppressing folios}%
  \fi}{\ClassError{\@classname}{The option printfolios can be either true or false}}
\define@cmdkey{@PNW@topmatter@}[@PNW@]{authorsperrow}[0]{%
  \IfInteger{#1}{\ClassInfo{\@classname}{Setting authorsperrow to
      #1}}{\ClassWarning{\@classname}{The parameter authorsperrow must be
      numerical. Ignoring the input #1}\gdef\@PNW@authorsperrow{0}}}
\def\settopmatter#1{\setkeys{@PNW@topmatter@}{#1}}
\settopmatter{printccs=true, printpnwref=true}
\if@PNW@manuscript
  \settopmatter{printfolios=true}
\else
  \if@PNW@journal
    \settopmatter{printfolios=true}
  \else
    \settopmatter{printfolios=false}
  \fi
\fi
\settopmatter{authorsperrow=0}
\def\@received{}
\newcommand\received[2][]{\def\@tempa{#1}%
  \ifx\@tempa\@empty
    \ifx\@received\@empty
      \gdef\@received{Received #2}%
    \else
      \g@addto@macro{\@received}{; revised #2}%
    \fi
  \else
    \ifx\@received\@empty
      \gdef\@received{#1 #2}%
    \else
      \g@addto@macro{\@received}{; #1 #2}%
    \fi
  \fi}
\AtEndDocument{%
  \ifx\@received\@empty\else
    \par\bigskip\noindent\small\normalfont\@received\par
  \fi}
\RequirePackage{comment}
\excludecomment{CCSXML}
\let\@concepts\@empty
\newcounter{@concepts}
\newcommand\ccsdesc[2][100]{%
  \ccsdesc@parse#1~#2~~\ccsdesc@parse@end}
\RequirePackage{textcomp}
\def\ccsdesc@parse#1~#2~#3~{%
  \stepcounter{@concepts}%
  \expandafter\ifx\csname CCS@General@#2\endcsname\relax
    \expandafter\gdef\csname CCS@General@#2\endcsname{\textbullet\
      \textbf{#2}}%
    \expandafter\gdef\csname CCS@Punctuation@#2\endcsname{; }%
    \expandafter\gdef\csname CCS@Specific@#2\endcsname{}%
  \g@addto@macro{\@concepts}{\csname CCS@General@#2\endcsname
    \csname CCS@Punctuation@#2\endcsname
    \csname CCS@Specific@#2\endcsname}%
  \fi
  \ifx#3\relax\relax\else
    \expandafter\gdef\csname CCS@Punctuation@#2\endcsname{
      \textrightarrow\ }%
    \expandafter\g@addto@macro\expandafter{\csname CCS@Specific@#2\endcsname}{%
     \addtocounter{@concepts}{-1}%
     \ifnum#1>499\textbf{#3}\else
     \ifnum#1>299\textit{#3}\else
     #3\fi\fi\ifnum\value{@concepts}=0.\else; \fi}%
  \fi
\ccsdesc@parse@finish}
\def\ccsdesc@parse@finish#1\ccsdesc@parse@end{}
\newif\if@printcopyright
\@printcopyrighttrue
\newif\if@printpermission
\@printpermissiontrue
\newif\if@pnwowned
\@pnwownedtrue
\define@choicekey*{PNW@}{pnwcopyrightmode}[%
  \pnw@copyrightinput\pnw@copyrightmode]{none,%
    pnwcopyright,pnwlicensed,rightsretained,%
    usgov,usgovmixed,cagov,cagovmixed,licensedusgovmixed,%
    licensedcagov,licensedcagovmixed,othergov,licensedothergov,%
    openaccess-1,openaccess-2}{%
  \@printpermissiontrue
  \@printcopyrighttrue
  \@pnwownedtrue
  \ifnum\pnw@copyrightmode=0\relax % none
   \@printpermissionfalse
   \@printcopyrightfalse
   \@pnwownedfalse
  \fi
  \ifnum\pnw@copyrightmode=2\relax % pnwlicensed
   \@pnwownedfalse
  \fi
  \ifnum\pnw@copyrightmode=3\relax % rightsretained
   \@pnwownedfalse
   \AtBeginDocument{\pnwPrice{}}%
  \fi
  \ifnum\pnw@copyrightmode=4\relax % usgov
   \@printpermissiontrue
   \@printcopyrightfalse
   \@pnwownedfalse
   \AtBeginDocument{\pnwPrice{}}%
  \fi
  \ifnum\pnw@copyrightmode=6\relax % cagov
   \@pnwownedfalse
  \fi
  \ifnum\pnw@copyrightmode=8\relax % licensedusgovmixed
   \@pnwownedfalse
  \fi
  \ifnum\pnw@copyrightmode=9\relax % licensedcagov
   \@pnwownedfalse
  \fi
  \ifnum\pnw@copyrightmode=10\relax % licensedcagovmixed
   \@pnwownedfalse
  \fi
  \ifnum\pnw@copyrightmode=11\relax % othergov
   \@pnwownedtrue
  \fi
  \ifnum\pnw@copyrightmode=12\relax % licensedothergov
   \@pnwownedfalse
  \fi
  \ifnum\pnw@copyrightmode=13\relax % openaccess-1
   \@pnwownedfalse
   \AtBeginDocument{\pnwPrice{}}%
  \fi
  \ifnum\pnw@copyrightmode=14\relax % openaccess-2
   \@pnwownedfalse
   \AtBeginDocument{\pnwPrice{}}%
  \fi}
\def\setcopyright#1{\setkeys{PNW@}{pnwcopyrightmode=#1}}
\setcopyright{pnwcopyright}
\def\@copyrightowner{%
  \ifcase\pnw@copyrightmode\relax % none
  \or % pnwcopyright
  PNW Press.
  \or % pnwlicensed
  Copyright held by the owner/author(s). Publication rights licensed to
  PNW\@.
  \or % rightsretained
  Copyright held by the owner/author(s).
  \or % usgov
  \or % usgovmixed
  PNW Press.
  \or % cagov
  Crown in Right of Canada.
  \or %cagovmixed
  PNW Press.
  \or %licensedusgovmixed
  Copyright held by the owner/author(s). Publication rights licensed to
  PNW\@.
  \or % licensedcagov
  Crown in Right of Canada. Publication rights licensed to
  PNW\@.
  \or %licensedcagovmixed
  Copyright held by the owner/author(s). Publication rights licensed to
  PNW\@.
  \or % othergov
  PNW Press.
  \or % licensedothergov
  Copyright held by the owner/author(s). Publication rights licensed to
  PNW\@.
  \fi}
\def\@formatdoi#1{\url{https://doi.org/#1}}
\def\@copyrightpermission{%
  \ifcase\pnw@copyrightmode\relax % none
  \or % pnwcopyright
   Permission to make digital or hard copies of all or part of this
   work for personal or classroom use is granted without fee provided
   that copies are not made or distributed for profit or commercial
   advantage and that copies bear this notice and the full citation on
   the first page. Copyrights for components of this work owned by
   others than PNW must be honored. Abstracting with credit is
   permitted. To copy otherwise, or republish, to post on servers or to
   redistribute to lists, requires prior specific permission
   and\hspace*{.5pt}/or  a fee. Request permissions from
   editor@pnwpress.org.
  \or % pnwlicensed
   Permission to make digital or hard copies of all or part of this
   work for personal or classroom use is granted without fee provided
   that copies are not made or distributed for profit or commercial
   advantage and that copies bear this notice and the full citation on
   the first page. Copyrights for components of this work owned by
   others than the author(s) must be honored. Abstracting with credit
   is permitted.  To copy otherwise, or republish, to post on servers
   or to  redistribute to lists, requires prior specific permission
   and\hspace*{.5pt}/or  a fee. Request permissions from
   permissions@pnw.org.
  \or % rightsretained
   Permission to make digital or hard copies of part or all of this work
   for personal or classroom use is granted without fee provided that
   copies are not made or distributed for profit or commercial advantage
   and that copies bear this notice and the full citation on the first
   page. Copyrights for third-party components of this work must be
   honored. For all other uses, contact the
   owner\hspace*{.5pt}/author(s).
  \or % usgov
   This paper is authored by an employee(s) of the United States
   Government and is in the public domain. Non-exclusive copying or
   redistribution is allowed, provided that the article citation is
   given and the authors and agency are clearly identified as its
   source.
  \or % usgovmixed
   PNW acknowledges that this contribution was authored or co-authored
   by an employee, contractor, or affiliate of the United States government. As such,
   the United States government retains a nonexclusive, royalty-free right to
   publish or reproduce this article, or to allow others to do so, for
   government purposes only.
  \or % cagov
   This article was authored by employees of the Government of Canada.
   As such, the Canadian government retains all interest in the
   copyright to this work and grants to PNW a nonexclusive,
   royalty-free right to publish or reproduce this article, or to allow
   others to do so, provided that clear attribution is given both to
   the authors and the Canadian government agency employing them.
   Permission to make digital or hard copies for personal or classroom
   use is granted. Copies must bear this notice and the full citation
   on the first page.  Copyrights for components of this work owned by
   others than the Canadian Government must be honored. To copy
   otherwise, distribute, republish, or post, requires prior specific
   permission and\hspace*{.5pt}/or a fee. Request permissions from
   permissions@pnw.org.
  \or % cagovmixed
   PNW acknowledges that this contribution was co-authored by an
   affiliate of the national government of Canada. As such, the Crown
   in Right of Canada retains an equal interest in the copyright.
   Reprints must include clear attribution to PNW and the author's
   government agency affiliation.  Permission to make digital or hard
   copies for personal or classroom use is granted.  Copies must bear
   this notice and the full citation on the first page. Copyrights for
   components of this work owned by others than PNW must be honored.
   To copy otherwise, distribute, republish, or post, requires prior
   specific permission and\hspace*{.5pt}/or a fee. Request permissions
   from permissions@pnw.org.
  \or % licensedusgovmixed
   Publication rights licensed to PNW\@. PNW acknowledges that this
   contribution was authored or co-authored by an employee, contractor
   or affiliate of the United States government. As such, the
   Government retains a nonexclusive, royalty-free right to publish or
   reproduce this article, or to allow others to do so, for Government
   purposes only.
  \or % licensedcagov
   This article was authored by employees of the Government of Canada.
   As such, the Canadian government retains all interest in the
   copyright to this work and grants to PNW a nonexclusive,
   royalty-free right to publish or reproduce this article, or to allow
   others to do so, provided that clear attribution is given both to
   the authors and the Canadian government agency employing them.
   Permission to make digital or hard copies for personal or classroom
   use is granted. Copies must bear this notice and the full citation
   on the first page.  Copyrights for components of this work owned by
   others than the Canadian Government must be honored. To copy
   otherwise, distribute, republish, or post, requires prior specific
   permission and\hspace*{.5pt}/or a fee. Request permissions from
   permissions@pnw.org.
  \or % licensedcagovmixed
   Publication rights licensed to PNW\@. PNW acknowledges that this
   contribution was authored or co-authored by an employee, contractor
   or affiliate of the national government of Canada. As such, the
   Government retains a nonexclusive, royalty-free right to publish or
   reproduce this article, or to allow others to do so, for Government
   purposes only.
  \or % othergov
   PNW acknowledges that this contribution was authored or co-authored
   by an employee, contractor or affiliate of a national government. As
   such, the Government retains a nonexclusive, royalty-free right to
   publish or reproduce this article, or to allow others to do so, for
   Government purposes only.
  \or % licensedothergov
   Publication rights licensed to PNW\@. PNW acknowledges that this
   contribution was authored or co-authored by an employee, contractor
   or affiliate of a national government. As such, the Government
   retains a nonexclusive, royalty-free right to publish or reproduce
   this article, or to allow others to do so, for Government purposes
   only.
 \or % openaccess-1
   This paper is published under the Creative Commons Attribution~4.0
   International (CC-BY~4.0) license. Authors reserve their rights to
   disseminate the work on their personal and corporate Web sites with
   the appropriate attribution.
 \or % openaccess-2
   This paper is published under the Creative Commons
   Attribution-NonCommercial-NoDerivs~4.0 International
   (CC-BY-NC-ND~4.0) license. Authors reserve their rights to
   disseminate the work on their personal and corporate web sites with the appropriate attribution.
 \fi}
\def\copyrightyear#1{\def\@copyrightyear{#1}}
\copyrightyear{\@pnwYear}
\def\@teaserfigures{}
\newenvironment{teaserfigure}{\Collect@Body\@saveteaser}{}
\long\def\@saveteaser#1{\g@addto@macro\@teaserfigures{\@teaser{#1}}}
\renewcommand{\thanks}[1]{%
  \@ifnotempty{#1}{%
    \if@PNW@anonymous
      \g@addto@macro\thankses{\thanks{A note}}%
   \else
    \g@addto@macro\thankses{\thanks{#1}}%
   \fi}}
\newbox\mktitle@bx
\def\maketitle{%
  \if@PNW@anonymous
    % Anonymize omission of \author-s
    \ifnum\num@authorgroups=0\author{}\fi
  \fi
  \begingroup
  \let\@footnotemark\@footnotemark@nolink
  \let\@footnotetext\@footnotetext@nolink
  \renewcommand\thefootnote{\@fnsymbol\c@footnote}%
  \hsize=\textwidth
  \def\@makefnmark{\hbox{\@textsuperscript{\@thefnmark}}}%
  \@mktitle\if@PNW@conferencemode\else\@mkauthors\fi\@mkteasers
  \@printtopmatter
  \if@PNW@conferencemode\@mkauthors\fi
  \setcounter{footnote}{0}%
  \def\@makefnmark{\hbox{\@textsuperscript{\normalfont\@thefnmark}}}%
  \@titlenotes
  \@subtitlenotes
  \@authornotes
  \let\@makefnmark\relax
  \let\@thefnmark\relax
  \let\@makefntext\noindent
  \ifx\@empty\thankses\else
    \footnotetextauthorsaddresses{%
      \def\par{\let\par\@par}\parindent\z@\@setthanks}%
  \fi
  \ifx\@empty\@authorsaddresses\else
     \if@PNW@anonymous\else
       \if@PNW@journal
         \footnotetextauthorsaddresses{%
           \def\par{\let\par\@par}\parindent\z@\@setauthorsaddresses}%
       \fi
     \fi
  \fi
  \if@PNW@nonpnw\else\footnotetextcopyrightpermission{%
    \if@PNW@authordraft
        \raisebox{-2ex}[\z@][\z@]{\makebox[0pt][l]{\large\bfseries
            Unpublished working draft. Not for distribution.}}%
       \color[gray]{0.9}%
    \fi
    \parindent\z@\parskip0.1\baselineskip
    \if@PNW@authorversion\else
      \if@printpermission\@copyrightpermission\par\fi
    \fi
    \if@PNW@manuscript\else
       \if@PNW@journal\else % Print the conference information
         {\itshape \pnwConference@shortname, \pnwConference@date, \pnwConference@venue}\par
       \fi
    \fi
    \if@printcopyright
      \copyright\ \@copyrightyear\ \@copyrightowner\\
    \else
      \@copyrightyear.\
    \fi
    \if@PNW@manuscript
      Manuscript submitted to PNW\\
    \else
      \if@PNW@authorversion
          This is the author's version of the work. It is posted here for
          your personal use. Not for redistribution. The definitive Version
          of Record was published in
          \if@PNW@journal
            \emph{\@journalName}%
          \else
            \emph{\@pnwBooktitle}%
          \fi
          \ifx\@pnwDOI\@empty
          .
          \else
            , \@formatdoi{\@pnwDOI}.
          \fi\\
        \else
          \if@PNW@nonpnw\else
            \if@PNW@journal
              % \@permissionCodeOne/\@pnwYear/\@pnwMonth-ART\@pnwArticle
              % \ifx\@pnwPrice\@empty\else\ \$\@pnwPrice\fi\\
              % \@formatdoi{\@pnwDOI}%
            \else % Conference
              \ifx\@pnwISBN\@empty\else PNW~ISBN~\@pnwISBN
              \ifx\@pnwPrice\@empty.\else\dots\$\@pnwPrice\fi\\\fi
              \ifx\@pnwDOI\@empty\else\@formatdoi{\@pnwDOI}\fi%
            \fi
          \fi
        \fi
      \fi}
    \fi
  \endgroup
  \setcounter{footnote}{0}%
  \@mkabstract
   \ifx\@keywords\@empty\else\bgroup
      {\if@PNW@journal
         \@specialsection{Keywords}%
       \else
         \@specialsection{Keywords}%
       \fi
         \@keywords}\par\egroup
   \fi
  \andify\authors
  \andify\shortauthors
  \global\let\authors=\authors
  \global\let\shortauthors=\shortauthors
  \if@PNW@printpnwref
     \@mkbibcitation
  \fi
  \hypersetup{%
    pdfauthor={\authors},
    pdftitle={\@title},
    pdfsubject={\@concepts},
    pdfkeywords={\@keywords},
    pdfcreator={LaTeX with pnwart
      \csname ver@pnwart.cls\endcsname\space
      and hyperref
      \csname ver@hyperref.sty\endcsname}}%
  \global\@topnum\z@ % this prevents floats from falling
                     % at the top of page 1
  \global\@botnum\z@ % we do not want them to be on the bottom either
  \@printendtopmatter
  \@afterindentfalse
  \@afterheading
}
\def\@specialsection#1{%
  \ifcase\PNW@format@nr
  \relax % manuscript
    \par\medskip\small\noindent#1: %
  \or % pnwsmall
    \par\medskip\small\noindent#1: %
  \or % pnwlarge
    \par\medskip\small\noindent#1: %
  \fi}
\def\@printtopmatter{%
  \ifx\@startPage\@empty
     \gdef\@startPage{1}%
  \else
     \setcounter{page}{\@startPage}%
  \fi
  \thispagestyle{firstpagestyle}%
  \noindent
  \ifcase\PNW@format@nr
  \relax % manuscript
    \box\mktitle@bx\par
  \or % pnwsmall
    \box\mktitle@bx\par
  \or % pnwlarge
    \box\mktitle@bx\par
    \par\box\mktitle@bx\par\bigskip
    \if@PNW@badge
       \marginpar{\noindent
         \ifx\@pnwBadgeL@image\@empty\else
           \href{\@pnwBadgeL@url}{%
             \includegraphics[width=\@PNW@badge@width]{\@pnwBadgeL@image}}%
            \hskip\@PNW@badge@skip
          \fi
         \ifx\@pnwBadgeR@image\@empty\else
           \href{\@pnwBadgeR@url}{%
             \includegraphics[width=\@PNW@badge@width]{\@pnwBadgeR@image}}%
          \fi}%
    \fi
  \fi
}
\def\@mktitle{%
  \ifcase\PNW@format@nr
  \relax % manuscript
    \@mktitle@i
  \or % pnwsmall
    \@mktitle@i
  \or % pnwlarge
    \@mktitle@i
  \fi
}
\def\@titlefont{%
  \ifcase\PNW@format@nr
  \relax % manuscript
    \LARGE\sffamily\bfseries
  \or % pnwsmall
    \LARGE\sffamily\bfseries
  \or % pnwlarge
    \LARGE\sffamily\bfseries
  \fi}
\def\@subtitlefont{\normalsize
  \ifcase\PNW@format@nr
  \relax % manuscript
    \mdseries
  \or % pnwsmall
    \mdseries
  \or % pnwlarge
    \mdseries
  \fi}
\def\@mktitle@i{\hsize=\textwidth
  \@PNW@title@width=\hsize
  \ifx\@pnwBadgeL@image\@empty\else
    \advance\@PNW@title@width by -\@PNW@badge@width
    \advance\@PNW@title@width by -\@PNW@badge@skip
  \fi
  \ifx\@pnwBadgeR@image\@empty\else
    \advance\@PNW@title@width by -\@PNW@badge@width
    \advance\@PNW@title@width by -\@PNW@badge@skip
  \fi
  \setbox\mktitle@bx=\vbox{\noindent\@titlefont
    \ifx\@pnwBadgeL@image\@empty\else
      \raisebox{-.5\baselineskip}[\z@][\z@]{\href{\@pnwBadgeL@url}{%
          \includegraphics[width=\@PNW@badge@width]{\@pnwBadgeL@image}}}%
      \hskip\@PNW@badge@skip
    \fi
    \parbox[t]{\@PNW@title@width}{\raggedright
      \@titlefont\noindent
      \@title
  \ifx\@subtitle\@empty\else
    \par\noindent{\@subtitlefont\@subtitle}
  \fi}%
  \ifx\@pnwBadgeR@image\@empty\else
    \hskip\@PNW@badge@skip
    \raisebox{-.5\baselineskip}[\z@][\z@]{\href{\@pnwBadgeR@url}{%
        \includegraphics[width=\@PNW@badge@width]{\@pnwBadgeR@image}}}%
  \fi
  \par\bigskip}}%
\def\@mktitle@iii{\hsize=\textwidth
    \setbox\mktitle@bx=\vbox{\@titlefont\centering
      \@PNW@title@width=\hsize
      \if@PNW@badge
        \advance\@PNW@title@width by -2\@PNW@badge@width
        \advance\@PNW@title@width by -2\@PNW@badge@skip
        \parbox[b]{\@PNW@badge@width}{\strut
          \ifx\@pnwBadgeL@image\@empty\else
            \raisebox{-.5\baselineskip}[\z@][\z@]{\href{\@pnwBadgeL@url}{%
                \includegraphics[width=\@PNW@badge@width]{\@pnwBadgeL@image}}}%
          \fi}%
        \hskip\@PNW@badge@skip
      \fi
      \parbox[t]{\@PNW@title@width}{\centering\@titlefont
        \@title
        \ifx\@subtitle\@empty\else
          \par\noindent{\@subtitlefont\@subtitle}
        \fi
      }%
      \if@PNW@badge
        \hskip\@PNW@badge@skip
        \parbox[b]{\@PNW@badge@width}{\strut
          \ifx\@pnwBadgeR@image\@empty\else
            \raisebox{-.5\baselineskip}[\z@][\z@]{\href{\@pnwBadgeR@url}{%
                \includegraphics[width=\@PNW@badge@width]{\@pnwBadgeR@image}}}%
          \fi}%
      \fi
      \par\bigskip}}%
\def\@mktitle@iv{\hsize=\textwidth
    \setbox\mktitle@bx=\vbox{\raggedright\leftskip5pc\@titlefont
      \noindent\leavevmode\leaders\hrule height 2pt\hfill\kern0pt\par
      \noindent\@title
     \ifx\@subtitle\@empty\else
       \par\noindent\@subtitlefont\@subtitle
     \fi
     \par\bigskip}}%
\newbox\@PNW@commabox
\def\@PNW@addtoaddress#1{%
  \ifvmode\else
    \if@PNW@affiliation@obeypunctuation\else
    \setbox\@PNW@commabox=\hbox{, }%
    \unskip\cleaders\copy\@PNW@commabox\hskip\wd\@PNW@commabox
  \fi\fi
  #1}
\def\streetaddress#1{\unskip\ignorespaces}
\def\postcode#1{\unskip\ignorespaces}
\if@PNW@journal
  \def\position#1{\unskip\ignorespaces}
  \def\institution#1{\unskip~#1\ignorespaces}
  \def\city#1{\unskip\ignorespaces}
  \def\state#1{\unskip\ignorespaces}
  \newcommand\department[2][0]{\unskip\ignorespaces}
  \def\country#1{\if@PNW@affiliation@obeypunctuation\else, \fi#1\ignorespaces}
\else
  \def\position#1{\if@PNW@affiliation@obeypunctuation#1\else#1\par\fi}%
  \def\institution#1{\if@PNW@affiliation@obeypunctuation#1\else#1\par\fi}%
  \newcommand\department[2][0]{\if@PNW@affiliation@obeypunctuation
    #2\else#2\par\fi}%
  \let\city\@PNW@addtoaddress
  \let\state\@PNW@addtoaddress
  \let\country\@PNW@addtoaddress
\fi
\def\@mkauthors{\begingroup
  \hsize=\textwidth
  \ifcase\PNW@format@nr
  \relax % manuscript
    \@mkauthors@i
  \or % pnwsmall
    \@mkauthors@i
  \or % pnwlarge
    \@mkauthors@i
  \fi
  \endgroup
}
\def\@authorfont{\Large\sffamily}
\def\@affiliationfont{\normalsize\normalfont}
\ifcase\PNW@format@nr
\relax % manuscript
\or % pnwsmall
  \def\@authorfont{\large\sffamily}
  \def\@affiliationfont{\small\normalfont}
\or % pnwlarge
\fi
\def\@typeset@author@line{%
  \andify\@currentauthors\par\noindent
  \@currentauthors\def\@currentauthors{}%
  \ifx\@currentaffiliations\@empty\else
    \andify\@currentaffiliations
      \unskip, {\@currentaffiliations}\par
  \fi
  \def\@currentaffiliations{}}
\def\@mkauthors@i{%
  \def\@currentauthors{}%
  \def\@currentaffiliations{}%
  \global\let\and\@typeset@author@line
  \def\@author##1{%
    \ifx\@currentauthors\@empty
      \gdef\@currentauthors{\@authorfont\MakeTextUppercase{##1}}%
    \else
       \g@addto@macro{\@currentauthors}{\and\MakeTextUppercase{##1}}%
    \fi
    \gdef\and{}}%
  \def\email##1##2{}%
  \def\affiliation##1##2{%
    \def\@tempa{##2}\ifx\@tempa\@empty\else
       \ifx\@currentaffiliations\@empty
          \gdef\@currentaffiliations{%
            \setkeys{@PNW@affiliation@}{obeypunctuation=false}%
            \setkeys{@PNW@affiliation@}{##1}%
            \@affiliationfont##2}%
       \else
         \g@addto@macro{\@currentaffiliations}{\and
           \setkeys{@PNW@affiliation@}{obeypunctuation=false}%
           \setkeys{@PNW@affiliation@}{##1}##2}%
      \fi
    \fi
     \global\let\and\@typeset@author@line}%
  \global\setbox\mktitle@bx=\vbox{\noindent\box\mktitle@bx\par\medskip
    \noindent\addresses\@typeset@author@line
   \par\medskip}%
}
\newbox\author@bx
\newdimen\author@bx@wd
\newskip\author@bx@sep
\author@bx@sep=1pc\relax
\def\@typeset@author@bx{\bgroup\hsize=\author@bx@wd\def\and{\par}%
  \global\setbox\author@bx=\vtop{\if@PNW@conferencemode\else\centering\fi
    \@authorfont\@currentauthors\par\@affiliationfont
    \@currentaffiliation}\egroup
  \box\author@bx\hspace{\author@bx@sep}%
  \gdef\@currentauthors{}%
  \gdef\@currentaffiliation{}}
\def\@mkauthors@iii{%
  \author@bx@wd=\textwidth\relax
  \advance\author@bx@wd by -\author@bx@sep\relax
  \ifnum\@PNW@authorsperrow>0\relax
    \divide\author@bx@wd by \@PNW@authorsperrow\relax
  \else
    \ifcase\num@authorgroups
    \relax % 0?
    \or  % 1=one author per row
    \or  % 2=two authors per row
       \divide\author@bx@wd by \num@authorgroups\relax
    \or  % 3=three authors per row
       \divide\author@bx@wd by \num@authorgroups\relax
    \or  % 4=two authors per row (!)
       \divide\author@bx@wd by 2\relax
    \else % three authors per row
       \divide\author@bx@wd by 3\relax
    \fi
  \fi
  \advance\author@bx@wd by -\author@bx@sep\relax
  \gdef\@currentauthors{}%
  \gdef\@currentaffiliation{}%
  \def\@author##1{\ifx\@currentauthors\@empty
    \gdef\@currentauthors{\par##1}%
  \else
    \g@addto@macro\@currentauthors{\par##1}%
  \fi
  \gdef\and{}}%
  \def\email##1##2{\ifx\@currentaffiliation\@empty
    \gdef\@currentaffiliation{\bgroup
      \mathchardef\UrlBreakPenalty=10000\nolinkurl{##2}\egroup}%
  \else
    \g@addto@macro\@currentaffiliation{\par\bgroup
      \mathchardef\UrlBreakPenalty=10000\nolinkurl{##2}\egroup}%
  \fi}%
  \def\affiliation##1##2{\ifx\@currentaffiliation\@empty
    \gdef\@currentaffiliation{%
      \setkeys{@PNW@affiliation@}{obeypunctuation=false}%
      \setkeys{@PNW@affiliation@}{##1}##2}%
  \else
    \g@addto@macro\@currentaffiliation{\par
      \setkeys{@PNW@affiliation@}{obeypunctuation=false}%
      \setkeys{@PNW@affiliation@}{##1}##2}%
  \fi
  \global\let\and\@typeset@author@bx
}%
  \hsize=\textwidth
  \global\setbox\mktitle@bx=\vbox{\noindent
    \box\mktitle@bx\par\medskip\leavevmode
    \lineskip=1pc\relax\centering\hspace*{-1em}%
    \addresses\let\and\@typeset@author@bx\and\par\bigskip}}
\def\@mkauthors@iv{%
  \author@bx@wd=\columnwidth\relax
  \advance\author@bx@wd by -\author@bx@sep\relax
  \ifnum\@PNW@authorsperrow>0\relax
    \divide\author@bx@wd by \@PNW@authorsperrow\relax
  \else
    \ifcase\num@authorgroups
    \relax % 0?
    \or  % 1=one author per row
    \else  % 2=two authors per row
       \divide\author@bx@wd by 2\relax
    \fi
  \fi
  \advance\author@bx@wd by -\author@bx@sep\relax
  \gdef\@currentauthors{}%
  \gdef\@currentaffiliation{}%
  \def\@author##1{\ifx\@currentauthors\@empty
    \gdef\@currentauthors{\par##1}%
  \else
    \g@addto@macro\@currentauthors{\par##1}%
  \fi
  \gdef\and{}}%
  \def\email##1##2{\ifx\@currentaffiliation\@empty
    \gdef\@currentaffiliation{\nolinkurl{##2}}%
  \else
    \g@addto@macro\@currentaffiliation{\par\nolinkurl{##2}}%
  \fi}%
  \def\affiliation##1##2{\ifx\@currentaffiliation\@empty
    \gdef\@currentaffiliation{%
      \setkeys{@PNW@affiliation@}{obeypunctuation=false}%
           \setkeys{@PNW@affiliation@}{##1}##2}%
  \else
    \g@addto@macro\@currentaffiliation{\par
      \setkeys{@PNW@affiliation@}{obeypunctuation=false}%
      \setkeys{@PNW@affiliation@}{##1}##2}%
  \fi
  \global\let\and\@typeset@author@bx}%
    \bgroup\hsize=\columnwidth
    \par\raggedright\leftskip=\z@
    \lineskip=1pc\noindent
    \addresses\let\and\@typeset@author@bx\and\par\bigskip\egroup}
\def\@mkauthorsaddresses{%
  \ifnum\num@authors>1\relax
  Correspondence: \else Correspondence: \fi
  \bgroup
  \def\streetaddress##1{\unskip\@addpunct, ##1}%
  \def\postcode##1{\unskip\@addpunct, ##1}%
  \def\position##1{\unskip\ignorespaces}%
  \def\institution##1{\unskip\@addpunct, ##1}%
  \def\city##1{\unskip\@addpunct, ##1}%
  \def\state##1{\unskip\@addpunct, ##1}%
  \renewcommand\department[2][0]{\unskip\@addpunct, ##2}%
  \def\country##1{\unskip\@addpunct, ##1}%
  \def\and{\unskip\@addpunct; }%
  \def\@author##1{##1}%
  \def\email##1##2{\unskip\@addpunct, \nolinkurl{##2}}%
  \addresses
  \egroup}
\def\@setaddresses{}
\def\@authornotemark{\g@addto@macro\@currentauthors{\footnotemark\relax}}
\def\@@authornotemark#1{\g@addto@macro\@currentauthors{\footnotemark[#1]}}
\def\@mkteasers{%
  \ifx\@teaserfigures\@empty\else
    \def\@teaser##1{\par\bigskip\bgroup
      \captionsetup{type=figure}##1\egroup\par}
    \global\setbox\mktitle@bx=\vbox{\noindent\box\mktitle@bx\par
      \noindent\@Description@presentfalse
      \@teaserfigures\par\if@Description@present\else
         \global\@undescribed@imagestrue
         \ClassWarning{\@classname}{A possible image without
           description}\fi
    \medskip}%
  \fi}
\def\@mkabstract{\bgroup
  \ifx\@abstract\@lempty\else
  {\phantomsection\addcontentsline{toc}{section}{Abstract}%
    \if@PNW@journal
       \everypar{\setbox\z@\lastbox\everypar{}}\small
    \else
      \section*{\abstractname}%
    \fi
   \ignorespaces\@abstract\par}%
  \fi\egroup}
\def\@mkbibcitation{\bgroup
  \def\@pages@word{\ifnum\getrefnumber{TotPages}=1\relax page\else pages\fi}%
  \def\footnotemark{}%
  \def\\{\unskip{} \ignorespaces}%
  \def\footnote{\ClassError{\@classname}{Please do not use footnotes
      inside a \string\title{} or \string\author{} command! Use
      \string\titlenote{} or \string\authornote{} instead!}}%
  \def\@article@string{\ifx\@pnwArticle\@empty{\ }\else,
    Article~\@pnwArticle\ \fi}%
  \par\medskip\small\noindent{\bfseries Reference Format:}\par\nobreak
  \noindent\bgroup
    \def\\{\unskip{}, \ignorespaces}\authors\egroup. \@pnwYear. \@title
  \ifx\@subtitle\@empty. \else: \@subtitle. \fi
  \if@PNW@nonpnw\else
    % The 'nonpnw' option disables 'printpnwref' by default,
    % and the present \@mkbibcitation definition is never used
    % in this case. The conditional remains useful if the user
    % explicitly sets \settopmatter{printpnwref=true}.
    \if@PNW@journal
       \textit{\@journalNameShort},
       Vol. \@pnwVolume \@article@string (\@pnwPubDate),
       \ref{TotPages}~\@pages@word.
    \else
       In \textit{\@pnwBooktitle}%
       \ifx\@pnwEditors\@empty\textit{.}\else
         \andify\@pnwEditors\textit{, }\@pnwEditors~\@editorsAbbrev.%
       \fi\
       PNW, New York, NY, USA%
         \@article@string\unskip, \ref{TotPages}~\@pages@word.
    \fi
  \fi
  \ifx\@pnwDOI\@empty\else\@formatdoi{\@pnwDOI}\fi
\par\egroup}
\def\@printendtopmatter{\par\bigskip}
\def\@setthanks{\long\def\thanks##1{\par##1\@addpunct.}\thankses}
\def\@setauthorsaddresses{\@authorsaddresses\unskip\@addpunct.}
\RequirePackage{fancyhdr}
\if@PNW@review
  \newsavebox{\PNW@linecount@bx}
  \newlength\PNW@linecount@bxht
  \newcount\PNW@linecount
  \PNW@linecount\@ne\relax
  \def\PNW@mk@linecount{%
    \savebox{\PNW@linecount@bx}[4em][t]{\parbox[t]{4em}{%
        \setlength{\PNW@linecount@bxht}{0pt}%
        \loop{\color{red}\scriptsize\the\PNW@linecount}\\
        \global\advance\PNW@linecount by \@ne
        \addtolength{\PNW@linecount@bxht}{\baselineskip}%
        \ifdim\PNW@linecount@bxht<\textheight\repeat
        {\color{red}\scriptsize\the\PNW@linecount}\hfill
        \global\advance\PNW@linecount by \@ne}}}
\fi
\def\PNW@linecountL{%
  \if@PNW@review
  \PNW@mk@linecount
  \begin{picture}(0,0)%
    \put(-26,-22){\usebox{\PNW@linecount@bx}}%
  \end{picture}%
  \fi}
\def\PNW@linecountR{%
  \if@PNW@review
  \PNW@mk@linecount
  \begin{picture}(0,0)%
    \put(20,-22){\usebox{\PNW@linecount@bx}}%
  \end{picture}%
  \fi}
\if@PNW@timestamp
  % Subtracting 30 from \time gives us the effect of rounding down despite
  % \numexpr rounding to nearest
  \newcounter{PNW@time@hours}
  \setcounter{PNW@time@hours}{\numexpr (\time - 30) / 60 \relax}
  \newcounter{PNW@time@minutes}
  \setcounter{PNW@time@minutes}{\numexpr \time - \thePNW@time@hours * 60 \relax}
  \newcommand\PNW@timestamp{%
    \footnotesize%
    \ifx\@pnwSubmissionID\@empty\relax\else
    Submission ID: \@pnwSubmissionID.{ }%
    \fi
    \the\year-\two@digits{\the\month}-\two@digits{\the\day}{ }%
    \two@digits{\thePNW@time@hours}:\two@digits{\thePNW@time@minutes}{. }%
    Page \thepage\ of \@startPage--\pageref*{TotPages}.%
  }
\fi
\def\@shortauthors{%
  \if@PNW@anonymous
    Anon.
    \ifx\@pnwSubmissionID\@empty\else Submission Id: \@pnwSubmissionID\fi
  \else\shortauthors\fi}
\def\@headfootfont{\sffamily}
\fancypagestyle{standardpagestyle}{%
  \fancyhf{}%
  \renewcommand{\headrulewidth}{\z@}%
  \renewcommand{\footrulewidth}{\z@}%
  \def\@pnwArticlePage{%
    \ifx\@pnwArticle\empty%
      \if@PNW@printfolios\thepage\fi%
    \else%
      \@pnwArticle\if@PNW@printfolios:\thepage\fi%
    \fi%
  }
  \ifcase\PNW@format@nr
  \relax % manuscript
    \fancyhead[LE]{\PNW@linecountL\if@PNW@printfolios\thepage\fi}%
    \fancyhead[RO]{\if@PNW@printfolios\thepage\fi}%
    \fancyhead[RE]{\@shortauthors}%
    \fancyhead[LO]{\PNW@linecountL\shorttitle}%
    \if@PNW@nonpnw\else%
      \fancyfoot[RO,LE]{\footnotesize Manuscript submitted to PNW}
    \fi%
  \or % pnwsmall
    \fancyhead[LE]{\PNW@linecountL\@headfootfont\@pnwArticlePage}%
    \fancyhead[RO]{\@headfootfont\@pnwArticlePage}%
    \fancyhead[RE]{\@headfootfont\@shortauthors}%
    \fancyhead[LO]{\PNW@linecountL\@headfootfont\shorttitle}%
    \if@PNW@nonpnw\else%
      \fancyfoot[RO,LE]{\footnotesize \@journalNameShort, Vol. \@pnwVolume, No.
      \@pnwNumber, Article \@pnwArticle.  Publication date: \@pnwPubDate.}%
    \fi%
  \or % pnwlarge
    \fancyhead[LE]{\PNW@linecountL\@headfootfont
      \@pnwArticlePage\quad\textbullet\quad\@shortauthors}%
    \fancyhead[LO]{\PNW@linecountL}%
    \fancyhead[RO]{\@headfootfont
      \shorttitle\quad\textbullet\quad\@pnwArticlePage}%
    \if@PNW@nonpnw\else%
      \fancyfoot[RO,LE]{\footnotesize \@journalNameShort, Vol. \@pnwVolume, No.
      \@pnwNumber, Article \@pnwArticle.  Publication date: \@pnwPubDate.}%
    \fi%
  \or % pnwtog
    \fancyhead[LE]{\PNW@linecountL\@headfootfont
      \@pnwArticlePage\quad\textbullet\quad\@shortauthors}%
    \fancyhead[LO]{\PNW@linecountL}%
    \fancyhead[RE]{\PNW@linecountR}%
    \fancyhead[RO]{\@headfootfont
      \shorttitle\quad\textbullet\quad\@pnwArticlePage\PNW@linecountR}%
    \if@PNW@nonpnw\else%
      \fancyfoot[RO,LE]{\footnotesize \@journalNameShort, Vol. \@pnwVolume, No.
      \@pnwNumber, Article \@pnwArticle.  Publication date: \@pnwPubDate.}%
    \fi%
  \else % Proceedings
    \fancyfoot[C]{\if@PNW@printfolios\footnotesize\thepage\fi}%
    \fancyhead[LO]{\PNW@linecountL\@headfootfont\shorttitle}%
    \fancyhead[RE]{\@headfootfont\@shortauthors\PNW@linecountR}%
    \if@PNW@nonpnw\else%
      \fancyhead[LE]{\PNW@linecountL\@headfootfont\pnwConference@shortname,
        \pnwConference@date, \pnwConference@venue}%
      \fancyhead[RO]{\@headfootfont\pnwConference@shortname,
        \pnwConference@date, \pnwConference@venue\PNW@linecountR}%
    \fi%
  \fi
  \if@PNW@timestamp
     \fancyfoot[LO,RE]{\PNW@timestamp}
  \fi
}
\pagestyle{standardpagestyle}
\newdimen\@folio@wd
\@folio@wd=\z@
\newdimen\@folio@ht
\@folio@ht=\z@
\newdimen\@folio@voffset
\@folio@voffset=\z@
\def\@folio@max{1}
\ifcase\PNW@format@nr
\relax % manuscript
\or % pnwsmall
  \@folio@wd=45.75pt\relax
  \@folio@ht=1.25in\relax
  \@folio@voffset=.2in\relax
  \def\@folio@max{8}
\or % pnwlarge
  \@folio@wd=43.25pt\relax
  \@folio@ht=79pt\relax
  \@folio@voffset=.55in\relax
  \def\@folio@max{10}
\fi
\def\@folioblob{\@tempcnta=0\@pnwArticleSeq\relax
  \ifnum\@tempcnta=0\relax\else
  \loop
     \ifnum\@tempcnta>\@folio@max\relax
      \advance\@tempcnta by - \@folio@max
   \repeat
    \advance\@tempcnta by -1\relax
    \@tempdima=\@folio@ht\relax
    \multiply\@tempdima by \the\@tempcnta\relax
    \advance\@tempdima by -\@folio@voffset\relax
    \begin{picture}(0,0)
    \makebox[\z@]{\raisebox{-\@tempdima}{%
        \rlap{%
          \raisebox{-0.45\@folio@ht}[\z@][\z@]{%
            \rule{\@folio@wd}{\@folio@ht}}}%
        \parbox{\@folio@wd}{%
          \centering
          \textcolor{white}{\LARGE\sffamily\bfseries\@pnwArticle}}}}
  \end{picture}\fi}

\fancypagestyle{firstpagestyle}{%
  \fancyhf{}%
  \renewcommand{\headrulewidth}{\z@}%
  \renewcommand{\footrulewidth}{\z@}%
  \ifcase\PNW@format@nr
  \relax % manuscript
    \fancyhead[L]{\PNW@linecountL}%
    \fancyfoot[RO,LE]{\if@PNW@printfolios\small\thepage\fi}%
    \if@PNW@nonpnw\else%
      \fancyfoot[RE,LO]{\footnotesize Manuscript submitted to PNW}%
    \fi%
  \or % pnwsmall
    \if@PNW@nonpnw\else%
      \fancyfoot[RO,LE]{\footnotesize \@journalNameShort, Vol. \@pnwVolume, No.
      \@pnwNumber, Article \@pnwArticle.  Publication date:
      \@pnwPubDate.}%
    \fi%
    \fancyhead[LE]{\PNW@linecountL\@folioblob}%
    \fancyhead[LO]{\PNW@linecountL}%
    \fancyhead[RO]{\@folioblob}%
    \fancyheadoffset[RO,LE]{0.6\@folio@wd}%
  \or % pnwlarge
    \if@PNW@nonpnw\else%
      \fancyfoot[RO,LE]{\footnotesize \@journalNameShort, Vol. \@pnwVolume, No.
      \@pnwNumber, Article \@pnwArticle.  Publication date:
      \@pnwPubDate.}%
    \fi%
    \fancyhead[RO]{\@folioblob}%
    \fancyhead[LE]{\PNW@linecountL\@folioblob}%
    \fancyhead[LO]{\PNW@linecountL}%
    \fancyheadoffset[RO,LE]{1.4\@folio@wd}%
  \or % pnwtog
    \if@PNW@nonpnw\else%
      \fancyfoot[RO,LE]{\footnotesize \@journalNameShort, Vol. \@pnwVolume, No.
      \@pnwNumber, Article \@pnwArticle.  Publication date:
      \@pnwPubDate.}%
    \fi%
    \fancyhead[L]{\PNW@linecountL}%
    \fancyhead[R]{\PNW@linecountR}%
  \else % Conference proceedings
    \fancyhead[L]{\PNW@linecountL}%
    \fancyhead[R]{\PNW@linecountR}%
    \fancyfoot[C]{\if@PNW@printfolios\footnotesize\thepage\fi}%
  \fi
  \if@PNW@timestamp
    \ifnum\PNW@format@nr=0\relax % Manuscript
    \fancyfoot[LO,RE]{\PNW@timestamp\quad
      \if@PNW@nonpnw\else
        \footnotesize Manuscript submitted to PNW
      \fi}
    \else
    \fancyfoot[LO,RE]{\PNW@timestamp}
    \fi
  \fi
}
\let\PNW@ps@plain\ps@plain
\let\PNW@ps@myheadings\ps@myheadings
\let\PNW@ps@headings\ps@headings
\def\PNW@restore@pagestyle{%
  \let\ps@plain\PNW@ps@plain
  \let\ps@myheadings\PNW@ps@myheadings
  \let\ps@headings\PNW@ps@headings}
\AtBeginDocument{\PNW@restore@pagestyle}
\def\PNW@NRadjust#1{%
 \begingroup
  \expandafter\ifx\csname Sectionformat\endcsname\relax
  % do nothing when  \Sectionformat  is unknown
   \def\next{\endgroup #1}%
 \else
  \def\next{\endgroup
   \let\realSectionformat\Sectionformat
   \def\PNW@sect@format@{#1}%
   \let\Sectionformat\PNW@NR@adjustedSectionformat
 %%  next lines added 2018-06-17 to ensure section number is styled
   \let\real@adddotafter\@adddotafter
   \let\@adddotafter\PNW@adddotafter
   #1{}% imposes the styles, but nullifies  \MakeUppercase
   \let\@adddotafter\real@adddotafter
  }%
 \fi \next
}
\def\PNW@NR@adjustedSectionformat#1#2{%
 \realSectionformat{\PNW@sect@format{#1}}{#2}%
 \let\Sectionformat\realSectionformat}
\DeclareRobustCommand{\PNW@sect@format}{\PNW@sect@format@}
\def\PNW@sect@format@null#1{#1}
\let\PNW@sect@format@\PNW@sect@format@null
\AtBeginDocument{%
 \expandafter\ifx\csname LTX@adddotafter\endcsname\relax
  \let\LTX@adddotafter\@adddotafter
 \fi
}
\def\PNW@adddotafter#1{\ifx\relax#1\relax\else\LTX@adddotafter{#1}\fi}
\renewcommand\section{\@startsection{section}{1}{\z@}%
  {-.75\baselineskip \@plus -2\p@ \@minus -.2\p@}%
  {.25\baselineskip}%
  {\PNW@NRadjust\@secfont}}
\renewcommand\subsection{\@startsection{subsection}{2}{\z@}%
  {-.75\baselineskip \@plus -2\p@ \@minus -.2\p@}%
  {.25\baselineskip}%
  {\PNW@NRadjust\@subsecfont}}
\renewcommand\subsubsection{\@startsection{subsubsection}{3}{\z@}%
  {-.5\baselineskip \@plus -2\p@ \@minus -.2\p@}%
  {-3.5\p@}%
  {\PNW@NRadjust{\@subsubsecfont\@adddotafter}}}
\renewcommand\paragraph{\@startsection{paragraph}{4}{\parindent}%
  {-.5\baselineskip \@plus -2\p@ \@minus -.2\p@}%
  {-3.5\p@}%
  {\PNW@NRadjust{\@parfont\@adddotafter}}}
\renewcommand\part{\@startsection{part}{9}{\z@}%
  {-10\p@ \@plus -4\p@ \@minus -2\p@}%
  {4\p@}%
  {\PNW@NRadjust\@parfont}}
\def\section@raggedright{\@rightskip\@flushglue
  \rightskip\@rightskip
  \leftskip\z@skip
  \parindent\z@}
\def\@secfont{\sffamily\bfseries\section@raggedright\MakeTextUppercase}
\def\@subsecfont{\sffamily\bfseries\section@raggedright}
\def\@subsubsecfont{\sffamily\itshape}
\def\@parfont{\itshape}
\setcounter{secnumdepth}{3}
\ifcase\PNW@format@nr
\relax % manuscript
\or % pnwsmall
\or % pnwlarge
 \def\@secfont{\sffamily\large\section@raggedright\MakeTextUppercase}
 \def\@subsecfont{\sffamily\large\section@raggedright}
\or % pnwtog
 \def\@secfont{\sffamily\large\section@raggedright\MakeTextUppercase}
 \def\@subsecfont{\sffamily\large\section@raggedright}
\or % sigconf
 \def\@secfont{\bfseries\Large\section@raggedright\MakeTextUppercase}
 \def\@subsecfont{\bfseries\Large\section@raggedright}
\or % siggraph
 \def\@secfont{\sffamily\bfseries\Large\section@raggedright\MakeTextUppercase}
 \def\@subsecfont{\sffamily\bfseries\Large\section@raggedright}
\or % sigplan
 \def\@secfont{\bfseries\Large\section@raggedright}
 \def\@subsecfont{\bfseries\section@raggedright}
 \renewcommand\subsubsection{\@startsection{subsubsection}{3}{\z@}%
   {-.75\baselineskip \@plus -2\p@ \@minus -.2\p@}%
   {.25\baselineskip}%
   {\@subsubsecfont}}
 \def\@subsubsecfont{\bfseries\section@raggedright}
 \renewcommand\paragraph{\@startsection{paragraph}{4}{\z@}%
   {-.5\baselineskip \@plus -2\p@ \@minus -.2\p@}%
   {-3.5\p@}%
   {\@parfont\@addspaceafter}}
 \def\@parfont{\bfseries\itshape}
 \renewcommand\subparagraph{\@startsection{subparagraph}{5}{\z@}%
   {-.5\baselineskip \@plus -2\p@ \@minus -.2\p@}%
   {-3.5\p@}%
   {\@subparfont\@addspaceafter}}
 \def\@subparfont{\itshape}
 \def\@secfont{\sffamily\bfseries\section@raggedright\MakeTextUppercase}
 \def\@subsecfont{\sffamily\bfseries\section@raggedright}
 \def\@secfont{\sffamily\bfseries\section@raggedright\MakeTextUppercase}
 \def\@subsecfont{\sffamily\bfseries\section@raggedright}
\fi
\def\@adddotafter#1{#1\@addpunct{.}}
\def\@addspaceafter#1{#1\@addpunct{\enspace}}
\providecommand*\@dotsep{4.5}
\def\@pnwplainbodyfont{\itshape}
\def\@pnwplainindent{\parindent}
\def\@pnwplainheadfont{\scshape}
\def\@pnwplainnotefont{\@empty}
\ifcase\PNW@format@nr
\relax % manuscript
\or % pnwsmall
\or % pnwlarge
\fi
\newtheoremstyle{pnwplain}%
  {.5\baselineskip\@plus.2\baselineskip
    \@minus.2\baselineskip}% space above
  {.5\baselineskip\@plus.2\baselineskip
    \@minus.2\baselineskip}% space below
  {\@pnwplainbodyfont}% body font
  {\@pnwplainindent}% indent amount
  {\@pnwplainheadfont}% head font
  {.}% punctuation after head
  {.5em}% spacing after head
  {\thmname{#1}\thmnumber{ #2}\thmnote{ {\@pnwplainnotefont(#3)}}}% head spec
\def\@pnwdefinitionbodyfont{\normalfont}
\def\@pnwdefinitionindent{\parindent}
\def\@pnwdefinitionheadfont{\itshape}
\def\@pnwdefinitionnotefont{\@empty}
\ifcase\PNW@format@nr
\relax % manuscript
\or % pnwsmall
\or % pnwlarge
\fi
\newtheoremstyle{pnwdefinition}%
  {.5\baselineskip\@plus.2\baselineskip
    \@minus.2\baselineskip}% space above
  {.5\baselineskip\@plus.2\baselineskip
    \@minus.2\baselineskip}% space below
  {\@pnwdefinitionbodyfont}% body font
  {\@pnwdefinitionindent}% indent amount
  {\@pnwdefinitionheadfont}% head font
  {.}% punctuation after head
  {.5em}% spacing after head
  {\thmname{#1}\thmnumber{ #2}\thmnote{ {\@pnwdefinitionnotefont(#3)}}}% head spec
\theoremstyle{pnwplain}
\AtEndPreamble{%
  \if@PNW@pnwthm
  \theoremstyle{pnwplain}
  \@ifundefined{theorem}{%
  \newtheorem{theorem}{Theorem}[section]
  }{}
  \@ifundefined{conjecture}{%
  \newtheorem{conjecture}[theorem]{Conjecture}
  }{}
  \@ifundefined{proposition}{%
  \newtheorem{proposition}[theorem]{Proposition}
  }{}
  \@ifundefined{lemma}{%
  \newtheorem{lemma}[theorem]{Lemma}
  }{}
  \@ifundefined{corollary}{%
  \newtheorem{corollary}[theorem]{Corollary}
  }{}
  \theoremstyle{pnwdefinition}
  \@ifundefined{example}{%
  \newtheorem{example}[theorem]{Example}
  }{}
  \@ifundefined{definition}{%
  \newtheorem{definition}[theorem]{Definition}
  }{}
  \fi
  \theoremstyle{pnwplain}
}
\def\@proofnamefont{\scshape}
\def\@proofindent{\indent}
\ifcase\PNW@format@nr
\relax % manuscript
\or % pnwsmall
\or % pnwlarge
\fi
\renewenvironment{proof}[1][\proofname]{\par
  \pushQED{\qed}%
  \normalfont \topsep6\p@\@plus6\p@\relax
  \trivlist
  \item[\@proofindent\hskip\labelsep
        {\@proofnamefont #1\@addpunct{.}}]\ignorespaces
}{%
  \popQED\endtrivlist\@endpefalse
}
\AtEndPreamble{%
  \if@PNW@balance
    \ifcase\PNW@format@nr
    \relax % manuscript
         \global\@PNW@balancefalse
       \or % pnwsmall
         \global\@PNW@balancefalse
       \or % pnwlarge
         \global\@PNW@balancefalse
    \fi
  \fi
}
\AtEndDocument{%
  \if@PNW@balance
  \if@twocolumn
  \balance
  \fi\fi}
\newcommand\acksname{Acknowledgments}
\specialcomment{acks}{%
  \begingroup
  \section*{\acksname}
  \phantomsection\addcontentsline{toc}{section}{\acksname}
}{%
  \endgroup
}
\def\grantsponsor#1#2#3{#2}
\newcommand\grantnum[3][]{#3%
  \def\@tempa{#1}\ifx\@tempa\@empty\else\space(\url{#1})\fi}
\AtEndPreamble{%
\if@PNW@screen
  \includecomment{screenonly}
  \excludecomment{printonly}
\else
  \excludecomment{screenonly}
  \includecomment{printonly}
\fi
\if@PNW@anonymous
  \excludecomment{anonsuppress}
  \excludecomment{acks}
\else
  \includecomment{anonsuppress}
\fi}
\newcommand\showeprint[2][arxiv]{%
  \def\@tempa{#1}%
  \ifx\@tempa\@empty\def\@tempa{arxiv}\fi
  \def\@tempb{arxiv}%
  \ifx\@tempa\@tempb
     arXiv:\href{http://arxiv.org/abs/#2}{#2}\else arXiv:#2%
  \fi}
\apptocmd{\@vspace}{\ClassWarning{\@classname}{\string\vspace\space should
    only be used to provide space above/below surrounding
    objects}}{}{}
\apptocmd{\@vspacer}{\ClassWarning{\@classname}{\string\vspace\space should
    only be used to provide space above/below surrounding
    objects}}{}{}
\let\PNW@origbaselinestretch\baselinestretch
\AtEndDocument{\ifx\baselinestretch\PNW@origbaselinestretch\else
  \ClassError{\@classname}{An attempt to redefine
    \string\baselinestretch\space detected!}\fi}
\normalsize\normalfont\frenchspacing
\endinput
%%
%% End of file `pnwart.cls'.
